@@ -9,12 +9,24 @@
 
 
 # KNOWN TYPES
-from mo_parsing import Forward, Group, Optional, MatchFirst, Literal, ZeroOrMore, export, set_parser_names
-from mo_parsing.infix import delimited_list, RIGHT_ASSOC, LEFT_ASSOC
+from mo_imports import export
+from mo_parsing import (
+    Forward,
+    Group,
+    Optional,
+    MatchFirst,
+    Literal,
+    ZeroOrMore,
+    set_parser_names,
+    delimited_list,
+    RIGHT_ASSOC,
+    LEFT_ASSOC,
+)
 
 from mo_sql_parsing.keywords import (
     RB,
     LB,
+    POS,
     NEG,
     NOT,
     BINARY_NOT,
@@ -47,12 +59,15 @@ BOOL = Group(keyword("bool")("op")) / to_json_call
 BOOLEAN = Group(keyword("boolean")("op")) / to_json_call
 DOUBLE = Group(keyword("double")("op") + Optional(flag("unsigned"))) / to_json_call
 FLOAT64 = Group(keyword("float64")("op")) / to_json_call
+BIGNUMERIC = Group(keyword("bignumeric")("op")) / to_json_call
+BIGDECIMAL = Group(keyword("bigdecimal")("op")) / to_json_call
 FLOAT = Group(keyword("float")("op") + Optional(flag("unsigned"))) / to_json_call
 GEOMETRY = Group(keyword("geometry")("op")) / to_json_call
 INTEGER = Group(keyword("integer")("op") + Optional(flag("unsigned"))) / to_json_call
 INT = (keyword("int")("op") + _size + Optional(flag("unsigned"))) / to_json_call
 INT32 = Group(keyword("int32")("op")) / to_json_call
 INT64 = Group(keyword("int64")("op")) / to_json_call
+BYTEINT = Group(keyword("byteint")("op")) / to_json_call
 REAL = Group(keyword("real")("op") + Optional(flag("unsigned"))) / to_json_call
 TEXT = Group(keyword("text")("op")) / to_json_call
 SMALLINT = Group(keyword("smallint")("op") + Optional(flag("unsigned"))) / to_json_call
@@ -120,6 +135,8 @@ simple_types << MatchFirst([
     DOUBLE_PRECISION,
     DOUBLE,
     FLOAT64,
+    BIGNUMERIC,
+    BIGDECIMAL,
     FLOAT,
     GEOMETRY,
     MAP_TYPE,
@@ -127,6 +144,7 @@ simple_types << MatchFirst([
     INT,
     INT32,
     INT64,
+    BYTEINT,
     JSON,
     NCHAR,
     NUMBER,
@@ -151,6 +169,7 @@ CASTING = (Literal("::").suppress() + simple_types("params")).set_parser_name("c
 KNOWN_OPS.insert(0, CASTING)
 
 unary_ops = {
+    POS: RIGHT_ASSOC,
     NEG: RIGHT_ASSOC,
     NOT: RIGHT_ASSOC,
     BINARY_NOT: RIGHT_ASSOC,
@@ -201,7 +220,8 @@ def get_column_type(expr, identifier, literal_string):
     )
 
     column_def_references = assign(
-        "references", identifier("table") + LB + delimited_list(identifier)("columns") + RB,
+        "references",
+        identifier("table") + LB + delimited_list(identifier)("columns") + RB,
     )
 
     column_options = ZeroOrMore(
